@@ -43,7 +43,6 @@
 #include "serverprovider.h"
 #include "set.h"
 #include "sqlparser.h"
-#include "sqlbuilder.h"
 #include "statement.h"
 #include "transactionstatus.h"
 #include "xatransaction.h"
@@ -79,7 +78,6 @@ GType gda_row_get_type(void);
 GType gda_server_operation_get_type(void);
 GType gda_server_provider_get_type(void);
 GType gda_set_get_type(void);
-GType gda_sql_builder_get_type(void);
 GType gda_sql_parser_get_type(void);
 GType gda_statement_get_type(void);
 GType gda_transaction_status_get_type(void);
@@ -91,9 +89,7 @@ GQuark gda_connection_error_quark(void);
 GQuark gda_data_model_iter_error_quark(void);
 GQuark gda_holder_error_quark(void);
 GQuark gda_meta_store_error_quark(void);
-GQuark gda_meta_struct_error_quark(void);
 GQuark gda_server_provider_error_quark(void);
-GQuark gda_sql_builder_error_quark(void);
 GQuark gda_sql_parser_error_quark(void);
 GQuark gda_statement_error_quark(void);
 } // extern "C"
@@ -127,7 +123,6 @@ namespace Gnome { namespace Gda {  class Row_Class { public: static Glib::Object
 namespace Gnome { namespace Gda {  class ServerOperation_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  } }
 namespace Gnome { namespace Gda {  class ServerProvider_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  } }
 namespace Gnome { namespace Gda {  class Set_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  } }
-namespace Gnome { namespace Gda {  class SqlBuilder_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  } }
 namespace Gnome { namespace Gda {  class SqlParser_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  } }
 namespace Gnome { namespace Gda {  class Statement_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  } }
 namespace Gnome { namespace Gda {  class TransactionStatus_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  } }
@@ -142,9 +137,7 @@ void wrap_init()
   Glib::Error::register_domain(gda_data_model_iter_error_quark(), &Gnome::Gda::DataModelIterError::throw_func);
   Glib::Error::register_domain(gda_holder_error_quark(), &Gnome::Gda::HolderError::throw_func);
   Glib::Error::register_domain(gda_meta_store_error_quark(), &Gnome::Gda::MetaStoreError::throw_func);
-  Glib::Error::register_domain(gda_meta_struct_error_quark(), &Gnome::Gda::MetaStructError::throw_func);
   Glib::Error::register_domain(gda_server_provider_error_quark(), &Gnome::Gda::ServerProviderError::throw_func);
-  Glib::Error::register_domain(gda_sql_builder_error_quark(), &Gnome::Gda::SqlBuilderError::throw_func);
   Glib::Error::register_domain(gda_sql_parser_error_quark(), &Gnome::Gda::SqlParserError::throw_func);
   Glib::Error::register_domain(gda_statement_error_quark(), &Gnome::Gda::StatementError::throw_func);
 
@@ -175,7 +168,6 @@ void wrap_init()
   Glib::wrap_register(gda_server_operation_get_type(), &Gnome::Gda::ServerOperation_Class::wrap_new);
   Glib::wrap_register(gda_server_provider_get_type(), &Gnome::Gda::ServerProvider_Class::wrap_new);
   Glib::wrap_register(gda_set_get_type(), &Gnome::Gda::Set_Class::wrap_new);
-  Glib::wrap_register(gda_sql_builder_get_type(), &Gnome::Gda::SqlBuilder_Class::wrap_new);
   Glib::wrap_register(gda_sql_parser_get_type(), &Gnome::Gda::SqlParser_Class::wrap_new);
   Glib::wrap_register(gda_statement_get_type(), &Gnome::Gda::Statement_Class::wrap_new);
   Glib::wrap_register(gda_transaction_status_get_type(), &Gnome::Gda::TransactionStatus_Class::wrap_new);
@@ -208,7 +200,6 @@ void wrap_init()
   Gnome::Gda::ServerOperation::get_type();
   Gnome::Gda::ServerProvider::get_type();
   Gnome::Gda::Set::get_type();
-  Gnome::Gda::SqlBuilder::get_type();
   Gnome::Gda::SqlParser::get_type();
   Gnome::Gda::Statement::get_type();
   Gnome::Gda::TransactionStatus::get_type();
